@@ -2,10 +2,9 @@
 require 5;
 package Pod::Simple::Methody;
 use strict;
-use utf8;
 use Pod::Simple ();
 use vars qw(@ISA $VERSION);
-$VERSION = '2.01';
+$VERSION = '3.29_3';
 @ISA = ('Pod::Simple');
 
 # Yes, we could use named variables, but I want this to be impose
@@ -33,7 +32,7 @@ sub _handle_element_end {
   ( $_[0]->can( 'end_' . $_[1] )
     || return
   )->(
-    $_[0]
+    $_[0], $_[2]
   );
 }
 
@@ -52,12 +51,12 @@ Pod::Simple::Methody -- turn Pod::Simple events into method calls
  use strict;
  package SomePodFormatter;
  use base qw(Pod::Simple::Methody);
- 
+
  sub handle_text {
    my($self, $text) = @_;
    ...
  }
- 
+
  sub start_head1 {
    my($self, $attrs) = @_;
    ...
@@ -66,7 +65,7 @@ Pod::Simple::Methody -- turn Pod::Simple events into method calls
    my($self) = @_;
    ...
  }
- 
+
 ...and start_/end_ methods for whatever other events you want to catch.
 
 =head1 DESCRIPTION
@@ -109,9 +108,22 @@ See the source for Pod::Simple::Text for an example of using this class.
 
 L<Pod::Simple>, L<Pod::Simple::Subclassing>
 
+=head1 SUPPORT
+
+Questions or discussion about POD and Pod::Simple should be sent to the
+pod-people@perl.org mail list. Send an empty email to
+pod-people-subscribe@perl.org to subscribe.
+
+This module is managed in an open GitHub repository,
+L<https://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
+
+Patches against Pod::Simple are welcome. Please send bug reports to
+<bug-pod-simple@rt.cpan.org>.
+
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.  All rights reserved.
+Copyright (c) 2002 Sean M. Burke.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -122,7 +134,19 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Sean M. Burke C<sburke@cpan.org>
+Pod::Simple was created by Sean M. Burke <sburke@cpan.org>.
+But don't bother him, he's retired.
+
+Pod::Simple is maintained by:
+
+=over
+
+=item * Allison Randal C<allison@perl.org>
+
+=item * Hans Dieter Pearcey C<hdp@cpan.org>
+
+=item * David E. Wheeler C<dwheeler@cpan.org>
+
+=back
 
 =cut
-
