@@ -3,7 +3,8 @@ use strict;
 package Pod::Simple::TiedOutFH;
 use Symbol ('gensym');
 use Carp ();
-use utf8;
+use vars qw($VERSION );
+$VERSION = '3.29_3';
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
